package org.eclipse.jnosql.test;

import com.mongodb.ConnectionString;
import com.mongodb.client.MongoClients;
import jakarta.annotation.PostConstruct;
import jakarta.annotation.PreDestroy;
import jakarta.enterprise.context.ApplicationScoped;
import jakarta.enterprise.inject.Produces;
import jakarta.inject.Inject;
import jakarta.servlet.ServletContext;
import java.util.function.Supplier;
import org.eclipse.jnosql.communication.document.DocumentManager;
import org.eclipse.jnosql.communication.document.DocumentManagerFactory;
import org.eclipse.jnosql.communication.mongodb.document.MongoDBDocumentConfiguration;

@ApplicationScoped
public class DocumentManagerProducer implements Supplier<DocumentManager> {

    public final static String MONGODB_URI_PROPERTY = "mongodb.url";
    
    @Inject 
    private ServletContext ctx;
    private DocumentManager manager;
    
    @PostConstruct
    public void init() {

        final String mongodb_url = ctx.getInitParameter(MONGODB_URI_PROPERTY);
        final ConnectionString con = new ConnectionString(mongodb_url);
        final DocumentManagerFactory factory = new MongoDBDocumentConfiguration()
                .get(MongoClients.create(con));
        
        manager = factory.apply(con.getDatabase());
    }
    
    @Produces
    public DocumentManager get() {
        return manager;
    }

    @PreDestroy
    public void destroy() {
        manager.close();
    }
}
